==> wiredash-0.2.0.tar.gz: lib/src/common/translation/l10n/messages_de.dart <==
import 'package:wiredash/wiredash.dart';

class WiredashLocalizedTranslations extends WiredashTranslations {
  const WiredashLocalizedTranslations() : super();
  @override
  String get captureSaveScreenshot => "Speichern";
  @override
  String get captureSkip => "Überspringen";
  @override
  String get captureSpotlightNavigateMsg =>
      "Navigiere zu dem Screen, auf welchem Du Feedback geben möchtest.";
  @override
  String get captureSpotlightNavigateTitle => "navigieren";
  @override
  String get captureSpotlightScreenCapturedMsg =>
      "Screenshot erstellt! Du kannst nun auf dem Bildschirm malen und so bestimmte Bereiche hervorheben.";
  @override
  String get captureSpotlightScreenCapturedTitle => "malen";
  @override
  String get captureTakeScreenshot => "Screenshot erstellen";
  @override
  String get feedbackBack => "Zurück";
  @override
  String get feedbackCancel => "Abbrechen";
  @override
  String get feedbackModeBugMsg =>
      "Wir leiten das dann an unser Expertenteam weiter.";
  @override
  String get feedbackModeBugTitle => "Melde einen Fehler";
  @override
  String get feedbackModeImprovementMsg =>
      "Hättest Du eine Idee, welche unsere App besser machen würde? Lass es uns wissen!";
  @override
  String get feedbackModeImprovementTitle => "Eine Idee einreichen";
  @override
  String get feedbackModePraiseMsg =>
      "Was genau gefällt Dir besonders gut - vielleicht können wir es ja noch ein bisschen besser machen?";
  @override
  String get feedbackModePraiseTitle => "Applaus senden";
  @override
  String get feedbackSave => "Speichern";
  @override
  String get feedbackSend => "Feedback senden";
  @override
  String get feedbackStateEmailMsg =>
      "Wenn Du über Neuigkeiten bezüglich Deines Feedbacks informiert werden möchtest, trage Deine Email ein.";
  @override
  String get feedbackStateEmailTitle => "Bleib auf dem Laufenden 👇";
  @override
  String get feedbackStateFeedbackMsg =>
      "Wir sind ganz Ohr. Bitte beschreibe Dein Anliegen so gut wie möglich, damit wir Dir helfen können.";
  @override
  String get feedbackStateIntroMsg =>
      "Wir können es kaum abwarten, Deine Gedanken zu unserer App zu hören! Was möchtest Du tun?";
  @override
  String get feedbackStateIntroTitle => "Hallo 👋";
  @override
  String get feedbackStateSuccessCloseMsg => "Danke für Dein Feedback!";
  @override
  String get feedbackStateSuccessCloseTitle => "Diesen Dialog schließen";
  @override
  String get feedbackStateSuccessMsg =>
      "Das wars auch schon. Danke, dass Du uns hilfst, eine bessere App zu entwickeln!";
  @override
  String get feedbackStateSuccessTitle => "Vielen Dank ✌️";
  @override
  String get inputHintEmail => "Deine Email";
  @override
  String get inputHintFeedback => "Dein Feedback";
  @override
  String get validationHintEmail =>
      "Bitte gib eine gültige Email an oder lasse das Feld frei.";
  @override
  String get validationHintFeedbackEmpty => "Bitte gib Dein Feedback ein.";
  @override
  String get validationHintFeedbackLength => "Dein Feedback ist zu lang.";
  @override
  String get feedbackStateFeedbackTitle => "Dein Feedback ✍️";
}

==> wiredash-0.6.2.tar.gz: lib/src/common/translation/l10n/messages_de.dart <==
import 'package:wiredash/wiredash.dart';

class WiredashLocalizedTranslations extends WiredashTranslations {
  const WiredashLocalizedTranslations() : super();
  @override
  String get captureSaveScreenshot => "Speichern";
  @override
  String get captureSkip => "Überspringen";
  @override
  String get captureSpotlightNavigateMsg =>
      "Navigiere zu dem Screen, auf welchem Du Feedback geben möchtest.";
  @override
  String get captureSpotlightNavigateTitle => "navigieren";
  @override
  String get captureSpotlightScreenCapturedMsg =>
      "Screenshot erstellt! Du kannst nun auf dem Bildschirm malen und so bestimmte Bereiche hervorheben.";
  @override
  String get captureSpotlightScreenCapturedTitle => "malen";
  @override
  String get captureTakeScreenshot => "Screenshot erstellen";
  @override
  String get feedbackBack => "Zurück";
  @override
  String get feedbackCancel => "Abbrechen";
  @override
  String get feedbackModeBugMsg =>
      "Wir leiten das dann an unser Expertenteam weiter.";
  @override
  String get feedbackModeBugTitle => "Melde einen Fehler";
  @override
  String get feedbackModeImprovementMsg =>
      "Hast Du eine Idee, die unsere App besser machen würde? Lass es uns wissen!";
  @override
  String get feedbackModeImprovementTitle => "Eine Idee einreichen";
  @override
  String get feedbackModePraiseMsg =>
      "Was genau gefällt Dir besonders gut - vielleicht können wir es ja noch ein bisschen besser machen?";
  @override
  String get feedbackModePraiseTitle => "Applaus senden";
  @override
  String get feedbackSave => "Speichern";
  @override
  String get feedbackSend => "Feedback senden";
  @override
  String get feedbackStateEmailMsg =>
      "Wenn Du über Neuigkeiten bezüglich Deines Feedbacks informiert werden möchtest, trage Deine Email ein.";
  @override
  String get feedbackStateEmailTitle => "Bleib auf dem Laufenden 👇";
  @override
  String get feedbackStateFeedbackMsg =>
      "Wir sind ganz Ohr. Bitte beschreibe Dein Anliegen so gut wie möglich, damit wir Dir helfen können.";
  @override
  String get feedbackStateIntroMsg =>
      "Wir können es kaum abwarten, Deine Gedanken zu unserer App zu hören! Was möchtest Du tun?";
  @override
  String get feedbackStateIntroTitle => "Hallo 👋";
  @override
  String get feedbackStateSuccessCloseMsg => "Danke für Dein Feedback!";
  @override
  String get feedbackStateSuccessCloseTitle => "Diesen Dialog schließen";
  @override
  String get feedbackStateSuccessMsg =>
      "Das wars auch schon. Danke, dass Du uns hilfst, eine bessere App zu entwickeln!";
  @override
  String get feedbackStateSuccessTitle => "Vielen Dank ✌️";
  @override
  String get inputHintEmail => "Deine Email";
  @override
  String get inputHintFeedback => "Dein Feedback";
  @override
  String get validationHintEmail =>
      "Bitte gib eine gültige Email an oder lasse das Feld frei.";
  @override
  String get validationHintFeedbackEmpty => "Bitte gib Dein Feedback ein.";
  @override
  String get validationHintFeedbackLength => "Dein Feedback ist zu lang.";
  @override
  String get feedbackStateFeedbackTitle => "Dein Feedback ✍️";
  @override
  String get firstPenLabel => "Ein dunkelbrauner Sift";
  @override
  String get secondPenLabel => "Ein grauweißer Stift";
  @override
  String get thirdPenLabel => "Ein türkiser Stift";
  @override
  String get fourthPenLabel => "Ein orangener Stift";
  @override
  String get companyLogoLabel => "Das Wiredash Logo";
  @override
  String get undoButtonLabel => "Letzte Änderung rückgängig machen";
  @override
  String get firstPenSelected => "Der dunkelbraune Stift ist ausgewählt";
  @override
  String get secondPenSelected => "Der grauweiße Stift ist ausgewählt";
  @override
  String get thirdPenSelected => "Der türkise Stift ist ausgewählt";
  @override
  String get fourthPenSelected => "Der orangene Stift ist ausgewählt";
}
